#!/usr/bin/env python3
# Copyright Metaswitch Networks - Highly Confidential Material
"""Manage credentials and environment variables."""
import logging
import os

from azure.identity import DefaultAzureCredential
from azure.keyvault.secrets import SecretClient


def populate_credentials():
    """Gets credentials from our Azure Keyvault and stores them as environment variables."""
    url = "https://tsunami-test-credentials.vault.azure.net"
    credential = DefaultAzureCredential()
    client = SecretClient(vault_url=url, credential=credential)

    logging.getLogger("SecretClient").setLevel(logging.WARNING)

    os.environ["NIPAP_USERNAME"] = client.get_secret("nipap-username").value
    os.environ["NIPAP_PASSWORD"] = client.get_secret("nipap-password").value
    os.environ["LANDSLIDE_USER_AGENT"] = client.get_secret("landslide-user-agent").value
    os.environ["LANDSLIDE_AUTHORIZATION"] = client.get_secret(
        "landslide-authorization"
    ).value

    logging.getLogger("SecretClient").setLevel(logging.DEBUG)


def clear_credentials():
    """Deletes all credentials stored as environment variables."""
    del os.environ["NIPAP_USERNAME"]
    del os.environ["NIPAP_PASSWORD"]
    del os.environ["LANDSLIDE_USER_AGENT"]
    del os.environ["LANDSLIDE_AUTHORIZATION"]
